/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvSignalBiquad.h"
#include "HvSignalLine.h"
#include "HvControlIf.h"
#include "HvSignalVar.h"
#include "HvControlSlice.h"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvMath.h"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvControlVar.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_xfmm8CsJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZSdYPgSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HxX3c4a2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aCLASHWl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_BQ3B6wsq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_WRNOpPu3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eDDwGNl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bcvFagLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HTPTmcdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_WAx1PSPg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_kKAlOtYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3HUoazRd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eEc3O8td_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wLhvNzGp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a0YzZg5w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8emcVp42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LjADqmH2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61877oPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nqa9e7ck_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wE322RTU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5j9jGJAY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xqc8vBKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4eTDFTES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YVG4r441_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LfpORCs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dlIqhZs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CSPEeE1J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rsQk3Uco_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xxeEKhu6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l9zVzKwt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iXJgsSLG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_SgJqrzYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9e6Lbnwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_M0jUUydk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HHRGLa0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z0V0X8BY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HoKfIKu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cCv83sQM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FqFRhyQn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G8J6FY6x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AjHX1RnB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4iSlYz5l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AdC1CTJV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lvMAWvgP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yPOn6avt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rXUPoDMw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZvYDjDyz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A0FE7YoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4pwhf7LU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zer4ns1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uyUJ0uYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wz8dqjFx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7RXTpq33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X31y9xQr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VhL3siJ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2h1NnYfW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7wlgAcKc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_24HNgeZY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2t9eaLoN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJImBRFT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nsqHCfrk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PJNq0Fd8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2JDbKQ4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A41hOS9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YjuCnJyO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Vt5zlAAu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aolb8T2H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E9S1zW5D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k480zVxm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QnGpI3zz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EEKtBZhf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bG2BQhSw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mQtmuHrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vZ8QHUiZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVAfYQeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ApuEXJaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_S1F6CUIi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_IM6GLCn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_C4z9Kby1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_J0VSFhFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_9hyqRfLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cZX5OH4R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1rMYI5tp_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_09ODfKs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Jzxt5vSo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_FltCVrc3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2lo4vuM1_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_r8QbUtAD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tB52nXMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jP5iRuk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_q2eY580Q_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_J1KLb0o8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_A4qGJ8kV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Tg2y2rM6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DVAjfVrm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wR2UeDde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0xhdtSES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GGTeN4Fl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZkGAxhDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WETIPFwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_kNjeDaJ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MFfpQsvG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DG4FzFN9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qFfEGClK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pozYyqAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yI2BnzA5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sCtULl82_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_v12I5oPs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IHnaejYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YzjD2r0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m0AHK69g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q7KeLEgC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VKWDHWK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BZ0RrdLW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hHvLcb9Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DngxixYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aP6NJBWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YKN7kkP7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UF5mxe0u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iudXxqZ2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iE4ySXlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zuMsIMrM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MPLV2Hnk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QGON7Gpi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_thchjqAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_4ejy3hEU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YUzNv9Jw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_txEqzvb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lW1Z7FtR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ymfFMjGC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_X1sne9wc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OKMSOTTm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_833qxwK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l4Etbe1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tZRMjLo6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T9HuFSFz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UlfoVLUR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aglgyIAG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6sfwloA9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FZZANUoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1SfD0WEn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UiFU52Ln_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c99v9u1w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xBTTTay8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BpYP0RH8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hPFTQsvM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2YFOOk5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MOwvIfGk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vZCbV2Sr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wujXK2JA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N9kHFul3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0ZNGxYap_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j5XCkRQh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gWg2T8tb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Bw8bWexh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ZQxKO1h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zVHZEl3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nhwgNV4M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_eN9kcSGw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7O1fGjgV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_11uW4S0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oHJx2jA1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_owfki8MN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i0llrnWP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_o0HhES5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_VGi5PhlN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KfiT4MGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6hiGz1m7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6cK92ZOK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5M3qeftq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yMt3lQO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SghY2J3x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gMjOsHky_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_764WJoYN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_edZWS0f1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MO9R1rLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cnK7yfa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_krvO9D1I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3MGtkGH6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_64QxZwtw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nVDNJocW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_WQgGYixP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RGW6ESgr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bKmll41J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6ub9qy5B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yfgN9ohe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XSyXKNVY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_362H4Xn4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3O9RP7qt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RukiJSx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QLcxlVrX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VN0qMEao_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qum97qRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bKuaNgiI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_waJQqhJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NOZRLo94_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QDBdkYyV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xrFEgvXB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g2oCoyGu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P5byT86u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gba5FbY4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_o9iRXjDf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lDOvX1Da_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_iZMxgLcp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_75hiNxdc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4qOYZxkI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HbIxdwKQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2PLPetR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YK7DyY21_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0UvWm4Iy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VZHD22dr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_s9wmqbuR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UPG2wGRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Va0Z7wKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3cPNF8oa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_alZSky3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f749opNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zl4RUCaB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OHxaDn8r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5QGOatF4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fIcjZq2Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XhEf6Wvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IwZQW30i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OQkXPBbo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bTH2rMcC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gV7WWXOs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lP36qW2x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W1K81YFA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k6zYM77r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5DxiZir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4896buxT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Q8BfpGfO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3tG01rl3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KjTLEyWJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1Yk0bvea_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RsBQqXBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ITTswfF3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DfLRtBLf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_r4i6VBw0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VQosbggK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fC711DlR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gkpJeAat_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YfyQ7oLe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZkfgMZjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vgr07wLO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KYfJR9jy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EdS6ko1m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7nkHV2xp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WBjsEYB3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8PZUKnFg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EQGbcvZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QldqDqrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A6Gn3uR7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1qNsLS3j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0G4xTFkC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PyX5MHFZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3GLYcGOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_reFbqf9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uxbGLp90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tqfpFaRH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_77JKZajD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nDpTDoUa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9RxX8SHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MB76BsGy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PYM2QIwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_5dXw1M7f_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Dc6hFHbY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aE9fhZjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fLAxXomw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1pv39uQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_G9BFKhDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3KA1OzP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_89ArdrEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ok0SkIn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HbFwYNXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YFzslw5m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XGaricDW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B1frDIEG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7p2cg6Sp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i3tGxGyR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pIVLr2Mp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h8MbmfLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YeJ6HWT2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_usneKqMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cQXNHvc2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6WRu0wBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mS8AZZbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ECh1JYbO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gmh2NWKq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qqHRS4OX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zwDgFzhU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XixvAWaL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_B7eEIN3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_s6DxMIdA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_pKFgsmae_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UOw15plc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_46NpLZqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XSlKFNSM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_B2t2cCqL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P3Jv261M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S2e55Z88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mfiVyvvH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AFW6gRiK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k7Fomori_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_GoYf6Y4G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PnjzaIXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZJnx1S3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d5jRCwTp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lVMtxKUc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V2lKSsd0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wm4eFh1H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IlUvGcZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uGhdF110_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yzGZ5vqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2jN5BfSu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wm7juNpq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_UR394G2i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Z11vxy2G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_d8xTFxYI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vS8jeIyu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xwma9IVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yky1f1bc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jeQVocl9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uYeCGvb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0sgcPkWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4yg3ntoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2YLH1TOh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gsANafHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7kr7sHBR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_poG5vtF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MBnKVj4N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3XKx0n74_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UfpFUprG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4KMVHEnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Tok9C0Uu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DCHZduUX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0b2H7ZAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WllA24qZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ci9WdWdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_NFGQaaGr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DbYjm8RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fcaABzOS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iqcV6cr3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_zM5lD5W2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DxQXCwfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rq1sqZHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gLPkuGdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_tn2p9a3c_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BePseq2O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FFdwLXKz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_YBGqZNoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2PKJQG4C_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_zsFgQiZP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z7TFCdZ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Zd0u3gx5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4CB1rDii_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PLyBfOWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_itZYoawt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h1Z7OWWW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HXrLQouy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N3XXhHsR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_sIeUTOYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_vycbWiuU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GAD8QANm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lPERncM5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QluHq54j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qpGm5N6Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KejDW5zF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ZLOI01k1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FkO8pMGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ImcMGHPw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CusdKP0e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YgBkynBt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mtl7731i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L0Jp3ucT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_h51rSdZG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j8gfGKxR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a5xZOZyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7M2rgUVF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mG1L2LMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_szFtIwM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cx325fxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXH10NZN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UcG0Oj3c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjII0z7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EomUcLpt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QFrTLucU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pfFkvaYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BedVp1qe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_njG7YLsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tu2AOL8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RmAOuEYK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yoqyp2eS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_60wyfQ4F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7BfLdVoI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I2mtf9y5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2U9gvUJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_02kAbH3a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OMbcImMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lvzwmU7Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6QaRt5XI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aUnZ5n4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UEH0HbrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_L20sRMLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YRhs00tm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3hi2STrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GUknplno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_17dOEdOj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v7SKOFyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zSnNWR3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zftvrUMJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_A8p7PdjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8L9NSlKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N9A1mVyf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kOxDNlu8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MtgZl2HV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xmxyztPp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6x0olbpL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_YhjNomGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3yjvQcgi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5X8aypks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WXJmtsER_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HEw27yOO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1rCFH8q9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mO5fsQRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_smmEiVIG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_dyUUyRMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ID2XXtAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wvNh7Ja8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bpwdd4sa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_98WtW6Om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7OENUNmH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p9hdCIs8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0JM6bob5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vr8hFrBA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AiBWmspn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VWzhGO0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nOf3baMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Dqobq5kX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vnmMFVtZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zu1hqXun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UKFsd2Ai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_KgcpRJf3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2VzdmYk2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oRWYx3aW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3ygur5vP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j3c0vabK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MpNpJvVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oXuQhBGd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d8JvBLyP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aNUf1S65_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S2lCjVm4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Jsrrg4tf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_abIYtoS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WdkBOy90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ldmyBX4o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qKB4t17C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wbOtfzic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Xd0FY8JL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HkwJwBzX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vP6rvu9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bIIE2v8m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8pj2Bffu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OG1jRA2g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gnawdwDw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HNjNn59Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QPxyICsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jbW2hm5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ICV4PYuG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_H1NNYtAX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8NlU8QLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4RzzHd7F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wb52pH7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_shQci16U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BqYIiGtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Z9pecVhg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_bhvP4XTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_igNuZw9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IVmVxVBs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8v3VNhhG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kKmulFqN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SdEOdlbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_oPsnOKjG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bBXxsExh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8ZD0BDmV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eKARZg2b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oGauMkzA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P5iDDf7v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tH55bjRu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7A6x9ZRp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bKcUn6ta_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OWsGOP47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_opAb5wpy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_VQSIvLki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ksKgwpfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_HBL8lOWv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RbG7OD92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kYEOU0mG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_qUITOhnm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JT2jnHXb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_9r4UhWXe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ydDWmf88_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8jbh0zWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NIhz5w4A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yV4mK74Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_do1H24U6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SJyglm68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YvaXVv5A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FUxvaqH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cIKv31BG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_V3FPeE38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EuWqEsoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oJccW5gi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JRWVa8Vp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6F5ZmoNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dPJCnzAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CIz1fxtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AplAEhQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dMhfmz7w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Z8anSeNH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DKsTrxbF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RickiXbi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9MFl4zYV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UO28TAir_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DwXrPztW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bGXoyzTn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_62Syh1Mf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bLy9H08s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_2XK1GOPW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SGYvu0NK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V3FE6hJ9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WyN97ZJu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fSyAvAXj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zHFS0uBk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UB9Arvkn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hjBowllz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fU6v2ryC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gLA9flvf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1AbQcg4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h8IuSoKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TH7e58og_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2I7W9b8B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w0LzNNlc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kpKOmhBu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yripBUfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BQ6QS5jN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MOK46JeK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S9p220vr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qCiMffLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QDm6r6sW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mBRjsbQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lBw1P239_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3eUb2Mvy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vjC8UlGb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uZiKGaHK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4CXtiqFd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_nb0EmIIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XBzMUAW9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iuJoMuaZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CpoOoIrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PP3FzxpC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ACMnY7hQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4aoqW1H9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e5kydQPC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cSFfVuDL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Ye53yNj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ToQr5GFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9SAmCMJ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YSjm2SNO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vA4epq47_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_dETiLOrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XKSRgq90_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bowaaJVh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xCW8jKfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2Vkkrjet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_P3pugtA2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YNPcNYxM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SjoHbvfA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k1rlzysn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k9nlq2Qx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ALMydOYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_m82Ti6fe;
  SignalLine sLine_gwx6banl;
  SignalLine sLine_tXeKiija;
  SignalLine sLine_7oieIj8y;
  SignalLine sLine_Q880YTkb;
  SignalBiquad sBiquad_s_O6ZIPI1t;
  SignalLine sLine_bjyTn0ul;
  SignalLine sLine_T6FJhdx3;
  SignalLine sLine_HWJnPhcd;
  SignalLine sLine_1yYRxGaP;
  SignalBiquad sBiquad_s_BQRSC4lJ;
  SignalLine sLine_HKtBKaOP;
  SignalLine sLine_lgKTRnOX;
  SignalLine sLine_EY7QtDDf;
  SignalLine sLine_x77LrN4I;
  SignalLine sLine_N0eC9Oiw;
  SignalBiquad sBiquad_s_oFICHk5h;
  SignalLine sLine_8eUUeNKB;
  SignalLine sLine_jhQBY1Ea;
  SignalLine sLine_CkFs0LQf;
  SignalLine sLine_c7k0EEGw;
  SignalLine sLine_WH4fj1en;
  SignalBiquad sBiquad_s_2uJWMuI7;
  SignalLine sLine_C9e6lydZ;
  SignalLine sLine_blevvN0Q;
  SignalLine sLine_v3BdW2jj;
  SignalLine sLine_BKnidlwI;
  SignalBiquad sBiquad_s_hUffdJsB;
  SignalLine sLine_XX3iJo8O;
  SignalLine sLine_1V0Pa2r9;
  SignalLine sLine_vRwebZIu;
  SignalLine sLine_Gmfg1MOu;
  SignalLine sLine_kSqeGiE9;
  SignalBiquad sBiquad_s_h5P6ClQn;
  ControlVar cVar_xfmm8CsJ;
  ControlVar cVar_ZSdYPgSw;
  ControlVar cVar_HxX3c4a2;
  ControlVar cVar_aCLASHWl;
  ControlSlice cSlice_WRNOpPu3;
  ControlVar cVar_eDDwGNl0;
  ControlVar cVar_HTPTmcdj;
  ControlIf cIf_WAx1PSPg;
  ControlIf cIf_kKAlOtYm;
  ControlBinop cBinop_eEc3O8td;
  ControlBinop cBinop_wLhvNzGp;
  ControlBinop cBinop_LjADqmH2;
  ControlBinop cBinop_61877oPR;
  ControlBinop cBinop_wE322RTU;
  ControlIf cIf_5j9jGJAY;
  ControlBinop cBinop_xqc8vBKV;
  ControlBinop cBinop_4eTDFTES;
  ControlBinop cBinop_LfpORCs8;
  ControlBinop cBinop_dlIqhZs8;
  ControlBinop cBinop_CSPEeE1J;
  ControlVar cVar_SgJqrzYK;
  ControlIf cIf_9e6Lbnwm;
  ControlIf cIf_M0jUUydk;
  ControlBinop cBinop_z0V0X8BY;
  ControlBinop cBinop_HoKfIKu9;
  ControlBinop cBinop_G8J6FY6x;
  ControlBinop cBinop_AjHX1RnB;
  ControlBinop cBinop_AdC1CTJV;
  ControlIf cIf_lvMAWvgP;
  ControlBinop cBinop_yPOn6avt;
  ControlBinop cBinop_rXUPoDMw;
  ControlBinop cBinop_A0FE7YoY;
  ControlBinop cBinop_4pwhf7LU;
  ControlBinop cBinop_Zer4ns1m;
  ControlVar cVar_VhL3siJ5;
  ControlIf cIf_2h1NnYfW;
  ControlIf cIf_7wlgAcKc;
  ControlBinop cBinop_2t9eaLoN;
  ControlBinop cBinop_ZJImBRFT;
  ControlBinop cBinop_O2JDbKQ4;
  ControlBinop cBinop_A41hOS9z;
  ControlBinop cBinop_Vt5zlAAu;
  ControlIf cIf_aolb8T2H;
  ControlBinop cBinop_E9S1zW5D;
  ControlBinop cBinop_k480zVxm;
  ControlBinop cBinop_EEKtBZhf;
  ControlBinop cBinop_bG2BQhSw;
  ControlBinop cBinop_mQtmuHrz;
  ControlIf cIf_IM6GLCn0;
  ControlSlice cSlice_J0VSFhFH;
  ControlVar cVar_9hyqRfLO;
  ControlSlice cSlice_09ODfKs8;
  ControlVar cVar_Jzxt5vSo;
  ControlSlice cSlice_r8QbUtAD;
  ControlVar cVar_tB52nXMq;
  ControlSlice cSlice_J1KLb0o8;
  ControlVar cVar_A4qGJ8kV;
  ControlBinop cBinop_qFfEGClK;
  ControlBinop cBinop_yI2BnzA5;
  ControlBinop cBinop_sCtULl82;
  ControlBinop cBinop_YzjD2r0e;
  ControlBinop cBinop_m0AHK69g;
  ControlBinop cBinop_Q7KeLEgC;
  ControlBinop cBinop_VKWDHWK4;
  ControlBinop cBinop_BZ0RrdLW;
  ControlVar cVar_hHvLcb9Y;
  ControlBinop cBinop_DngxixYs;
  ControlBinop cBinop_aP6NJBWN;
  ControlBinop cBinop_YKN7kkP7;
  ControlBinop cBinop_UF5mxe0u;
  ControlBinop cBinop_iudXxqZ2;
  ControlBinop cBinop_iE4ySXlu;
  ControlBinop cBinop_zuMsIMrM;
  ControlBinop cBinop_QGON7Gpi;
  ControlVar cVar_thchjqAv;
  ControlVar cVar_4ejy3hEU;
  ControlBinop cBinop_833qxwK4;
  ControlBinop cBinop_l4Etbe1M;
  ControlBinop cBinop_tZRMjLo6;
  ControlBinop cBinop_UlfoVLUR;
  ControlBinop cBinop_aglgyIAG;
  ControlBinop cBinop_6sfwloA9;
  ControlBinop cBinop_FZZANUoc;
  ControlBinop cBinop_1SfD0WEn;
  ControlBinop cBinop_UiFU52Ln;
  ControlBinop cBinop_11uW4S0t;
  ControlBinop cBinop_owfki8MN;
  ControlBinop cBinop_i0llrnWP;
  ControlBinop cBinop_KfiT4MGf;
  ControlBinop cBinop_6hiGz1m7;
  ControlBinop cBinop_6cK92ZOK;
  ControlBinop cBinop_5M3qeftq;
  ControlBinop cBinop_yMt3lQO1;
  ControlBinop cBinop_SghY2J3x;
  ControlBinop cBinop_gMjOsHky;
  ControlBinop cBinop_edZWS0f1;
  ControlVar cVar_MO9R1rLq;
  ControlVar cVar_cnK7yfa4;
  ControlVar cVar_krvO9D1I;
  ControlBinop cBinop_6ub9qy5B;
  ControlBinop cBinop_yfgN9ohe;
  ControlBinop cBinop_XSyXKNVY;
  ControlBinop cBinop_3O9RP7qt;
  ControlBinop cBinop_RukiJSx2;
  ControlBinop cBinop_QLcxlVrX;
  ControlBinop cBinop_VN0qMEao;
  ControlBinop cBinop_Qum97qRr;
  ControlBinop cBinop_VZHD22dr;
  ControlBinop cBinop_UPG2wGRz;
  ControlBinop cBinop_Va0Z7wKU;
  ControlBinop cBinop_f749opNe;
  ControlBinop cBinop_zl4RUCaB;
  ControlBinop cBinop_OHxaDn8r;
  ControlBinop cBinop_5QGOatF4;
  ControlBinop cBinop_fIcjZq2Z;
  ControlBinop cBinop_IwZQW30i;
  ControlBinop cBinop_bTH2rMcC;
  ControlBinop cBinop_gV7WWXOs;
  ControlBinop cBinop_W1K81YFA;
  ControlBinop cBinop_k6zYM77r;
  ControlBinop cBinop_L5DxiZir;
  ControlBinop cBinop_Q8BfpGfO;
  ControlVar cVar_3tG01rl3;
  ControlVar cVar_KjTLEyWJ;
  ControlVar cVar_1Yk0bvea;
  ControlBinop cBinop_gkpJeAat;
  ControlBinop cBinop_YfyQ7oLe;
  ControlBinop cBinop_ZkfgMZjA;
  ControlBinop cBinop_KYfJR9jy;
  ControlBinop cBinop_EdS6ko1m;
  ControlBinop cBinop_7nkHV2xp;
  ControlBinop cBinop_WBjsEYB3;
  ControlBinop cBinop_8PZUKnFg;
  ControlBinop cBinop_EQGbcvZ0;
  ControlBinop cBinop_nDpTDoUa;
  ControlBinop cBinop_MB76BsGy;
  ControlBinop cBinop_PYM2QIwS;
  SignalVarf sVarf_GSO9aFv3;
  SignalVarf sVarf_nn0B6IAv;
  SignalVarf sVarf_Yia3d8cc;
  ControlSlice cSlice_Dc6hFHbY;
  ControlVar cVar_aE9fhZjS;
  ControlVar cVar_1pv39uQo;
  ControlIf cIf_G9BFKhDg;
  ControlIf cIf_3KA1OzP9;
  ControlBinop cBinop_Ok0SkIn6;
  ControlBinop cBinop_HbFwYNXs;
  ControlBinop cBinop_B1frDIEG;
  ControlBinop cBinop_7p2cg6Sp;
  ControlBinop cBinop_pIVLr2Mp;
  ControlIf cIf_h8MbmfLP;
  ControlBinop cBinop_YeJ6HWT2;
  ControlBinop cBinop_usneKqMU;
  ControlBinop cBinop_6WRu0wBr;
  ControlBinop cBinop_mS8AZZbj;
  ControlBinop cBinop_ECh1JYbO;
  ControlVar cVar_B7eEIN3t;
  ControlIf cIf_s6DxMIdA;
  ControlIf cIf_pKFgsmae;
  ControlBinop cBinop_46NpLZqS;
  ControlBinop cBinop_XSlKFNSM;
  ControlBinop cBinop_S2e55Z88;
  ControlBinop cBinop_mfiVyvvH;
  ControlBinop cBinop_k7Fomori;
  ControlIf cIf_GoYf6Y4G;
  ControlBinop cBinop_PnjzaIXq;
  ControlBinop cBinop_ZJnx1S3W;
  ControlBinop cBinop_lVMtxKUc;
  ControlBinop cBinop_V2lKSsd0;
  ControlBinop cBinop_Wm4eFh1H;
  ControlVar cVar_wm7juNpq;
  ControlIf cIf_UR394G2i;
  ControlIf cIf_Z11vxy2G;
  ControlBinop cBinop_vS8jeIyu;
  ControlBinop cBinop_xwma9IVT;
  ControlBinop cBinop_uYeCGvb4;
  ControlBinop cBinop_0sgcPkWU;
  ControlBinop cBinop_2YLH1TOh;
  ControlIf cIf_gsANafHX;
  ControlBinop cBinop_7kr7sHBR;
  ControlBinop cBinop_poG5vtF9;
  ControlBinop cBinop_3XKx0n74;
  ControlBinop cBinop_UfpFUprG;
  ControlBinop cBinop_4KMVHEnF;
  ControlIf cIf_ci9WdWdn;
  ControlSlice cSlice_DbYjm8RG;
  ControlVar cVar_fcaABzOS;
  ControlSlice cSlice_DxQXCwfv;
  ControlVar cVar_rq1sqZHW;
  ControlSlice cSlice_BePseq2O;
  ControlVar cVar_FFdwLXKz;
  ControlSlice cSlice_zsFgQiZP;
  ControlVar cVar_Z7TFCdZ5;
  ControlBinop cBinop_lPERncM5;
  ControlBinop cBinop_qpGm5N6Y;
  ControlBinop cBinop_KejDW5zF;
  ControlBinop cBinop_ImcMGHPw;
  ControlBinop cBinop_CusdKP0e;
  ControlBinop cBinop_YgBkynBt;
  ControlBinop cBinop_Mtl7731i;
  ControlBinop cBinop_L0Jp3ucT;
  ControlVar cVar_h51rSdZG;
  ControlBinop cBinop_j8gfGKxR;
  ControlBinop cBinop_a5xZOZyw;
  ControlBinop cBinop_7M2rgUVF;
  ControlBinop cBinop_mG1L2LMs;
  ControlBinop cBinop_szFtIwM1;
  ControlBinop cBinop_cx325fxF;
  ControlBinop cBinop_vXH10NZN;
  ControlBinop cBinop_CjII0z7G;
  ControlVar cVar_EomUcLpt;
  ControlVar cVar_QFrTLucU;
  ControlBinop cBinop_60wyfQ4F;
  ControlBinop cBinop_7BfLdVoI;
  ControlBinop cBinop_I2mtf9y5;
  ControlBinop cBinop_02kAbH3a;
  ControlBinop cBinop_OMbcImMB;
  ControlBinop cBinop_lvzwmU7Y;
  ControlBinop cBinop_6QaRt5XI;
  ControlBinop cBinop_aUnZ5n4n;
  ControlBinop cBinop_UEH0HbrG;
  ControlBinop cBinop_WXJmtsER;
  ControlBinop cBinop_1rCFH8q9;
  ControlBinop cBinop_mO5fsQRU;
  ControlBinop cBinop_ID2XXtAV;
  ControlBinop cBinop_wvNh7Ja8;
  ControlBinop cBinop_Bpwdd4sa;
  ControlBinop cBinop_98WtW6Om;
  ControlBinop cBinop_7OENUNmH;
  ControlBinop cBinop_p9hdCIs8;
  ControlBinop cBinop_0JM6bob5;
  ControlBinop cBinop_AiBWmspn;
  ControlVar cVar_VWzhGO0i;
  ControlVar cVar_nOf3baMo;
  ControlVar cVar_Dqobq5kX;
  ControlBinop cBinop_3ygur5vP;
  ControlBinop cBinop_j3c0vabK;
  ControlBinop cBinop_MpNpJvVV;
  ControlBinop cBinop_d8JvBLyP;
  ControlBinop cBinop_aNUf1S65;
  ControlBinop cBinop_S2lCjVm4;
  ControlBinop cBinop_Jsrrg4tf;
  ControlBinop cBinop_abIYtoS4;
  ControlBinop cBinop_4RzzHd7F;
  ControlBinop cBinop_shQci16U;
  ControlBinop cBinop_BqYIiGtD;
  ControlBinop cBinop_igNuZw9x;
  ControlBinop cBinop_IVmVxVBs;
  ControlBinop cBinop_8v3VNhhG;
  ControlBinop cBinop_kKmulFqN;
  ControlBinop cBinop_SdEOdlbH;
  ControlBinop cBinop_bBXxsExh;
  ControlBinop cBinop_eKARZg2b;
  ControlBinop cBinop_oGauMkzA;
  ControlBinop cBinop_tH55bjRu;
  ControlBinop cBinop_7A6x9ZRp;
  ControlBinop cBinop_bKcUn6ta;
  ControlBinop cBinop_opAb5wpy;
  ControlVar cVar_VQSIvLki;
  ControlVar cVar_ksKgwpfx;
  ControlVar cVar_HBL8lOWv;
  ControlBinop cBinop_8jbh0zWo;
  ControlBinop cBinop_NIhz5w4A;
  ControlBinop cBinop_yV4mK74Z;
  ControlBinop cBinop_SJyglm68;
  ControlBinop cBinop_YvaXVv5A;
  ControlBinop cBinop_FUxvaqH1;
  ControlBinop cBinop_cIKv31BG;
  ControlBinop cBinop_V3FPeE38;
  ControlBinop cBinop_EuWqEsoa;
  ControlBinop cBinop_9MFl4zYV;
  ControlBinop cBinop_DwXrPztW;
  ControlBinop cBinop_bGXoyzTn;
  SignalVarf sVarf_tTh6khHZ;
  SignalVarf sVarf_odIvW8qv;
  SignalVarf sVarf_qChAGPLP;
  ControlVar cVar_62Syh1Mf;
  ControlVar cVar_bLy9H08s;
  ControlBinop cBinop_zHFS0uBk;
  ControlBinop cBinop_UB9Arvkn;
  ControlBinop cBinop_hjBowllz;
  ControlBinop cBinop_gLA9flvf;
  ControlBinop cBinop_1AbQcg4Z;
  ControlBinop cBinop_h8IuSoKE;
  ControlBinop cBinop_TH7e58og;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
