/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_m82Ti6fe);
  numBytes += sLine_init(&sLine_gwx6banl);
  numBytes += sLine_init(&sLine_tXeKiija);
  numBytes += sLine_init(&sLine_7oieIj8y);
  numBytes += sLine_init(&sLine_Q880YTkb);
  numBytes += sBiquad_init(&sBiquad_s_O6ZIPI1t);
  numBytes += sLine_init(&sLine_bjyTn0ul);
  numBytes += sLine_init(&sLine_T6FJhdx3);
  numBytes += sLine_init(&sLine_HWJnPhcd);
  numBytes += sLine_init(&sLine_1yYRxGaP);
  numBytes += sBiquad_init(&sBiquad_s_BQRSC4lJ);
  numBytes += sLine_init(&sLine_HKtBKaOP);
  numBytes += sLine_init(&sLine_lgKTRnOX);
  numBytes += sLine_init(&sLine_EY7QtDDf);
  numBytes += sLine_init(&sLine_x77LrN4I);
  numBytes += sLine_init(&sLine_N0eC9Oiw);
  numBytes += sBiquad_init(&sBiquad_s_oFICHk5h);
  numBytes += sLine_init(&sLine_8eUUeNKB);
  numBytes += sLine_init(&sLine_jhQBY1Ea);
  numBytes += sLine_init(&sLine_CkFs0LQf);
  numBytes += sLine_init(&sLine_c7k0EEGw);
  numBytes += sLine_init(&sLine_WH4fj1en);
  numBytes += sBiquad_init(&sBiquad_s_2uJWMuI7);
  numBytes += sLine_init(&sLine_C9e6lydZ);
  numBytes += sLine_init(&sLine_blevvN0Q);
  numBytes += sLine_init(&sLine_v3BdW2jj);
  numBytes += sLine_init(&sLine_BKnidlwI);
  numBytes += sBiquad_init(&sBiquad_s_hUffdJsB);
  numBytes += sLine_init(&sLine_XX3iJo8O);
  numBytes += sLine_init(&sLine_1V0Pa2r9);
  numBytes += sLine_init(&sLine_vRwebZIu);
  numBytes += sLine_init(&sLine_Gmfg1MOu);
  numBytes += sLine_init(&sLine_kSqeGiE9);
  numBytes += sBiquad_init(&sBiquad_s_h5P6ClQn);
  numBytes += cVar_init_f(&cVar_xfmm8CsJ, 0.0f);
  numBytes += cVar_init_f(&cVar_ZSdYPgSw, 0.0f);
  numBytes += cVar_init_f(&cVar_HxX3c4a2, 0.0f);
  numBytes += cVar_init_f(&cVar_aCLASHWl, 0.0f);
  numBytes += cSlice_init(&cSlice_WRNOpPu3, 1, -1);
  numBytes += cVar_init_f(&cVar_eDDwGNl0, 1337.0f);
  numBytes += cVar_init_f(&cVar_HTPTmcdj, 0.0f);
  numBytes += cIf_init(&cIf_WAx1PSPg, false);
  numBytes += cIf_init(&cIf_kKAlOtYm, false);
  numBytes += cBinop_init(&cBinop_eEc3O8td, 0.0f); // __pow
  numBytes += cIf_init(&cIf_5j9jGJAY, false);
  numBytes += cBinop_init(&cBinop_LfpORCs8, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_dlIqhZs8, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_CSPEeE1J, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_SgJqrzYK, 0.0f);
  numBytes += cIf_init(&cIf_9e6Lbnwm, false);
  numBytes += cIf_init(&cIf_M0jUUydk, false);
  numBytes += cBinop_init(&cBinop_z0V0X8BY, 0.0f); // __pow
  numBytes += cIf_init(&cIf_lvMAWvgP, false);
  numBytes += cBinop_init(&cBinop_A0FE7YoY, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4pwhf7LU, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Zer4ns1m, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_VhL3siJ5, 0.0f);
  numBytes += cIf_init(&cIf_2h1NnYfW, false);
  numBytes += cIf_init(&cIf_7wlgAcKc, false);
  numBytes += cBinop_init(&cBinop_2t9eaLoN, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aolb8T2H, false);
  numBytes += cBinop_init(&cBinop_EEKtBZhf, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_bG2BQhSw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_mQtmuHrz, -15.0f); // __eq
  numBytes += cIf_init(&cIf_IM6GLCn0, false);
  numBytes += cSlice_init(&cSlice_J0VSFhFH, 1, -1);
  numBytes += cVar_init_f(&cVar_9hyqRfLO, 0.0f);
  numBytes += cSlice_init(&cSlice_09ODfKs8, 1, -1);
  numBytes += cVar_init_f(&cVar_Jzxt5vSo, 0.0f);
  numBytes += cSlice_init(&cSlice_r8QbUtAD, 1, -1);
  numBytes += cVar_init_f(&cVar_tB52nXMq, 0.0f);
  numBytes += cSlice_init(&cSlice_J1KLb0o8, 1, -1);
  numBytes += cVar_init_f(&cVar_A4qGJ8kV, 0.313f);
  numBytes += cBinop_init(&cBinop_yI2BnzA5, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_sCtULl82, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_hHvLcb9Y, 0.0f);
  numBytes += cVar_init_f(&cVar_thchjqAv, 1337.0f);
  numBytes += cVar_init_f(&cVar_4ejy3hEU, 0.3f);
  numBytes += cBinop_init(&cBinop_l4Etbe1M, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aglgyIAG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6sfwloA9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FZZANUoc, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1SfD0WEn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UiFU52Ln, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_owfki8MN, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_i0llrnWP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_MO9R1rLq, 0.0f);
  numBytes += cVar_init_f(&cVar_cnK7yfa4, 1337.0f);
  numBytes += cVar_init_f(&cVar_krvO9D1I, 0.313f);
  numBytes += cBinop_init(&cBinop_yfgN9ohe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_RukiJSx2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_QLcxlVrX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VN0qMEao, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qum97qRr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UPG2wGRz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_Va0Z7wKU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_3tG01rl3, 0.0f);
  numBytes += cVar_init_f(&cVar_KjTLEyWJ, 1037.0f);
  numBytes += cVar_init_f(&cVar_1Yk0bvea, 0.4f);
  numBytes += cBinop_init(&cBinop_YfyQ7oLe, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EdS6ko1m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7nkHV2xp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WBjsEYB3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8PZUKnFg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EQGbcvZ0, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GSO9aFv3, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nn0B6IAv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Yia3d8cc, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_Dc6hFHbY, 1, -1);
  numBytes += cVar_init_f(&cVar_aE9fhZjS, 1337.0f);
  numBytes += cVar_init_f(&cVar_1pv39uQo, 0.0f);
  numBytes += cIf_init(&cIf_G9BFKhDg, false);
  numBytes += cIf_init(&cIf_3KA1OzP9, false);
  numBytes += cBinop_init(&cBinop_Ok0SkIn6, 0.0f); // __pow
  numBytes += cIf_init(&cIf_h8MbmfLP, false);
  numBytes += cBinop_init(&cBinop_6WRu0wBr, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_mS8AZZbj, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_ECh1JYbO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_B7eEIN3t, 0.0f);
  numBytes += cIf_init(&cIf_s6DxMIdA, false);
  numBytes += cIf_init(&cIf_pKFgsmae, false);
  numBytes += cBinop_init(&cBinop_46NpLZqS, 0.0f); // __pow
  numBytes += cIf_init(&cIf_GoYf6Y4G, false);
  numBytes += cBinop_init(&cBinop_lVMtxKUc, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_V2lKSsd0, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Wm4eFh1H, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_wm7juNpq, 0.0f);
  numBytes += cIf_init(&cIf_UR394G2i, false);
  numBytes += cIf_init(&cIf_Z11vxy2G, false);
  numBytes += cBinop_init(&cBinop_vS8jeIyu, 0.0f); // __pow
  numBytes += cIf_init(&cIf_gsANafHX, false);
  numBytes += cBinop_init(&cBinop_3XKx0n74, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_UfpFUprG, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_4KMVHEnF, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ci9WdWdn, false);
  numBytes += cSlice_init(&cSlice_DbYjm8RG, 1, -1);
  numBytes += cVar_init_f(&cVar_fcaABzOS, 0.0f);
  numBytes += cSlice_init(&cSlice_DxQXCwfv, 1, -1);
  numBytes += cVar_init_f(&cVar_rq1sqZHW, 0.0f);
  numBytes += cSlice_init(&cSlice_BePseq2O, 1, -1);
  numBytes += cVar_init_f(&cVar_FFdwLXKz, 0.0f);
  numBytes += cSlice_init(&cSlice_zsFgQiZP, 1, -1);
  numBytes += cVar_init_f(&cVar_Z7TFCdZ5, 0.313f);
  numBytes += cBinop_init(&cBinop_qpGm5N6Y, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_KejDW5zF, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_h51rSdZG, 0.0f);
  numBytes += cVar_init_f(&cVar_EomUcLpt, 1337.0f);
  numBytes += cVar_init_f(&cVar_QFrTLucU, 0.3f);
  numBytes += cBinop_init(&cBinop_7BfLdVoI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OMbcImMB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lvzwmU7Y, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_6QaRt5XI, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aUnZ5n4n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UEH0HbrG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1rCFH8q9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mO5fsQRU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VWzhGO0i, 0.0f);
  numBytes += cVar_init_f(&cVar_nOf3baMo, 1337.0f);
  numBytes += cVar_init_f(&cVar_Dqobq5kX, 0.313f);
  numBytes += cBinop_init(&cBinop_j3c0vabK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aNUf1S65, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_S2lCjVm4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Jsrrg4tf, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_abIYtoS4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_shQci16U, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_BqYIiGtD, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_VQSIvLki, 0.0f);
  numBytes += cVar_init_f(&cVar_ksKgwpfx, 1037.0f);
  numBytes += cVar_init_f(&cVar_HBL8lOWv, 0.4f);
  numBytes += cBinop_init(&cBinop_NIhz5w4A, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YvaXVv5A, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FUxvaqH1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_cIKv31BG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_V3FPeE38, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EuWqEsoa, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_tTh6khHZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_odIvW8qv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qChAGPLP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_62Syh1Mf, 5705.6f);
  numBytes += cVar_init_f(&cVar_bLy9H08s, 313.3f);
  numBytes += cBinop_init(&cBinop_zHFS0uBk, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_UB9Arvkn, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_hjBowllz, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qCiMffLq_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mBRjsbQ5_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QDm6r6sW_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ALMydOYB_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vjC8UlGb_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uZiKGaHK_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lBw1P239_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3eUb2Mvy_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4CXtiqFd_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CpoOoIrf_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iuJoMuaZ_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XBzMUAW9_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4aoqW1H9_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ACMnY7hQ_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PP3FzxpC_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Ye53yNj8_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cSFfVuDL_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e5kydQPC_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YSjm2SNO_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vA4epq47_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ToQr5GFC_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9SAmCMJ8_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dETiLOrf_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xCW8jKfK_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bowaaJVh_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XKSRgq90_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YNPcNYxM_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P3pugtA2_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2Vkkrjet_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k9nlq2Qx_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k1rlzysn_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SjoHbvfA_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nb0EmIIX_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_xfmm8CsJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2I7W9b8B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ZSdYPgSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w0LzNNlc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_HxX3c4a2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kpKOmhBu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_aCLASHWl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yripBUfc_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fSyAvAXj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WyN97ZJu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V3FE6hJ9_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_BQ3B6wsq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_WRNOpPu3, 0, m, &cSlice_WRNOpPu3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2lo4vuM1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_WRNOpPu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_bcvFagLR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_bcvFagLR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_eDDwGNl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bcvFagLR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_bcvFagLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lBw1P239_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_HTPTmcdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_xqc8vBKV_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_WAx1PSPg, 0, m, &cIf_WAx1PSPg_sendMessage);
}

void Heavy_WSTD_3Q::cIf_WAx1PSPg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4eTDFTES_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_kKAlOtYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_nqa9e7ck_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_61877oPR_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_3HUoazRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEc3O8td, HV_BINOP_POW, 0, m, &cBinop_eEc3O8td_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eEc3O8td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5j9jGJAY, 0, m, &cIf_5j9jGJAY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wLhvNzGp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_wE322RTU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_a0YzZg5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LjADqmH2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8emcVp42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kKAlOtYm, 0, m, &cIf_kKAlOtYm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LjADqmH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_kKAlOtYm, 1, m, &cIf_kKAlOtYm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_61877oPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_wLhvNzGp_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_nqa9e7ck_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_5j9jGJAY, 0, m, &cIf_5j9jGJAY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wE322RTU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eEc3O8td, HV_BINOP_POW, 1, m, &cBinop_eEc3O8td_sendMessage);
  cMsg_3HUoazRd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_5j9jGJAY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_GSO9aFv3, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_xqc8vBKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WAx1PSPg, 1, m, &cIf_WAx1PSPg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4eTDFTES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlIqhZs8, HV_BINOP_GREATER_THAN, 1, m, &cBinop_dlIqhZs8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CSPEeE1J, HV_BINOP_EQ, 1, m, &cBinop_CSPEeE1J_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YVG4r441_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_LfpORCs8, HV_BINOP_ADD, 0, m, &cBinop_LfpORCs8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_LfpORCs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a0YzZg5w_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8emcVp42_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dlIqhZs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5j9jGJAY, 1, m, &cIf_5j9jGJAY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CSPEeE1J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rsQk3Uco_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_rsQk3Uco_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GSO9aFv3, m);
}

void Heavy_WSTD_3Q::cCast_xxeEKhu6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HTPTmcdj, 0, m, &cVar_HTPTmcdj_sendMessage);
}

void Heavy_WSTD_3Q::cCast_l9zVzKwt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YVG4r441_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_iXJgsSLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LfpORCs8, HV_BINOP_ADD, 1, m, &cBinop_LfpORCs8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dlIqhZs8, HV_BINOP_GREATER_THAN, 0, m, &cBinop_dlIqhZs8_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CSPEeE1J, HV_BINOP_EQ, 0, m, &cBinop_CSPEeE1J_sendMessage);
}

void Heavy_WSTD_3Q::cVar_SgJqrzYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_yPOn6avt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_9e6Lbnwm, 0, m, &cIf_9e6Lbnwm_sendMessage);
}

void Heavy_WSTD_3Q::cIf_9e6Lbnwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rXUPoDMw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_M0jUUydk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4iSlYz5l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_AjHX1RnB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_HHRGLa0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_z0V0X8BY, HV_BINOP_POW, 0, m, &cBinop_z0V0X8BY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_z0V0X8BY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lvMAWvgP, 0, m, &cIf_lvMAWvgP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HoKfIKu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_AdC1CTJV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_cCv83sQM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_G8J6FY6x_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FqFRhyQn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M0jUUydk, 0, m, &cIf_M0jUUydk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_G8J6FY6x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M0jUUydk, 1, m, &cIf_M0jUUydk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AjHX1RnB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HoKfIKu9_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4iSlYz5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_lvMAWvgP, 0, m, &cIf_lvMAWvgP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AdC1CTJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z0V0X8BY, HV_BINOP_POW, 1, m, &cBinop_z0V0X8BY_sendMessage);
  cMsg_HHRGLa0p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_lvMAWvgP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nDpTDoUa_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MB76BsGy_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PYM2QIwS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_yPOn6avt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9e6Lbnwm, 1, m, &cIf_9e6Lbnwm_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rXUPoDMw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pwhf7LU, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4pwhf7LU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zer4ns1m, HV_BINOP_EQ, 1, m, &cBinop_Zer4ns1m_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_ZvYDjDyz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0FE7YoY, HV_BINOP_ADD, 0, m, &cBinop_A0FE7YoY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A0FE7YoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cCv83sQM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FqFRhyQn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4pwhf7LU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lvMAWvgP, 1, m, &cIf_lvMAWvgP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zer4ns1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uyUJ0uYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_uyUJ0uYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nDpTDoUa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MB76BsGy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_PYM2QIwS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Wz8dqjFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SgJqrzYK, 0, m, &cVar_SgJqrzYK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7RXTpq33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZvYDjDyz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_X31y9xQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A0FE7YoY, HV_BINOP_ADD, 1, m, &cBinop_A0FE7YoY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4pwhf7LU, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4pwhf7LU_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zer4ns1m, HV_BINOP_EQ, 0, m, &cBinop_Zer4ns1m_sendMessage);
}

void Heavy_WSTD_3Q::cVar_VhL3siJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_E9S1zW5D_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2h1NnYfW, 0, m, &cIf_2h1NnYfW_sendMessage);
}

void Heavy_WSTD_3Q::cIf_2h1NnYfW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_k480zVxm_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_7wlgAcKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_YjuCnJyO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_A41hOS9z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_24HNgeZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t9eaLoN, HV_BINOP_POW, 0, m, &cBinop_2t9eaLoN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2t9eaLoN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aolb8T2H, 0, m, &cIf_aolb8T2H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZJImBRFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Vt5zlAAu_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nsqHCfrk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_O2JDbKQ4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PJNq0Fd8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7wlgAcKc, 0, m, &cIf_7wlgAcKc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O2JDbKQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7wlgAcKc, 1, m, &cIf_7wlgAcKc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A41hOS9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_ZJImBRFT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_YjuCnJyO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aolb8T2H, 0, m, &cIf_aolb8T2H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Vt5zlAAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2t9eaLoN, HV_BINOP_POW, 1, m, &cBinop_2t9eaLoN_sendMessage);
  cMsg_24HNgeZY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_aolb8T2H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_Yia3d8cc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_E9S1zW5D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2h1NnYfW, 1, m, &cIf_2h1NnYfW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k480zVxm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bG2BQhSw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bG2BQhSw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQtmuHrz, HV_BINOP_EQ, 1, m, &cBinop_mQtmuHrz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_QnGpI3zz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EEKtBZhf, HV_BINOP_ADD, 0, m, &cBinop_EEKtBZhf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EEKtBZhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nsqHCfrk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PJNq0Fd8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bG2BQhSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aolb8T2H, 1, m, &cIf_aolb8T2H_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mQtmuHrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vZ8QHUiZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_vZ8QHUiZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Yia3d8cc, m);
}

void Heavy_WSTD_3Q::cCast_GVAfYQeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EEKtBZhf, HV_BINOP_ADD, 1, m, &cBinop_EEKtBZhf_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_bG2BQhSw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bG2BQhSw_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mQtmuHrz, HV_BINOP_EQ, 0, m, &cBinop_mQtmuHrz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ApuEXJaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VhL3siJ5, 0, m, &cVar_VhL3siJ5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_S1F6CUIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QnGpI3zz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_IM6GLCn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_nn0B6IAv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_C4z9Kby1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_J0VSFhFH, 0, m, &cSlice_J0VSFhFH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1rMYI5tp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_J0VSFhFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cZX5OH4R_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cZX5OH4R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_9hyqRfLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cZX5OH4R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_cZX5OH4R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vjC8UlGb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_1rMYI5tp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_09ODfKs8, 0, m, &cSlice_09ODfKs8_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BQ3B6wsq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_09ODfKs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FltCVrc3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FltCVrc3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Jzxt5vSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FltCVrc3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_FltCVrc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4CXtiqFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_2lo4vuM1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_r8QbUtAD, 0, m, &cSlice_r8QbUtAD_sendMessage);
      break;
    }
    default: {
      cSwitchcase_q2eY580Q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_r8QbUtAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_jP5iRuk5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_jP5iRuk5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_tB52nXMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jP5iRuk5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_jP5iRuk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uZiKGaHK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_q2eY580Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_J1KLb0o8, 0, m, &cSlice_J1KLb0o8_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_J1KLb0o8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Tg2y2rM6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Tg2y2rM6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_A4qGJ8kV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Tg2y2rM6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Tg2y2rM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3eUb2Mvy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_DVAjfVrm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m82Ti6fe, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_wR2UeDde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gwx6banl, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0xhdtSES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tXeKiija, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_GGTeN4Fl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_7oieIj8y, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ZkGAxhDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Q880YTkb, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_WETIPFwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_kNjeDaJ8_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_kNjeDaJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yI2BnzA5, HV_BINOP_DIVIDE, 1, m, &cBinop_yI2BnzA5_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pozYyqAJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MFfpQsvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_qFfEGClK_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_DG4FzFN9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MFfpQsvG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qFfEGClK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yI2BnzA5, HV_BINOP_DIVIDE, 0, m, &cBinop_yI2BnzA5_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pozYyqAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DG4FzFN9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yI2BnzA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sCtULl82, HV_BINOP_MULTIPLY, 1, m, &cBinop_sCtULl82_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_sCtULl82_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YUzNv9Jw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_txEqzvb4_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_v12I5oPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lW1Z7FtR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_IHnaejYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ymfFMjGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YzjD2r0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_m0AHK69g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m0AHK69g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_sCtULl82, HV_BINOP_MULTIPLY, 0, m, &cBinop_sCtULl82_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Q7KeLEgC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_VKWDHWK4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VKWDHWK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OKMSOTTm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BZ0RrdLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hHvLcb9Y, 1, m, &cVar_hHvLcb9Y_sendMessage);
}

void Heavy_WSTD_3Q::cVar_hHvLcb9Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T9HuFSFz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DngxixYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aglgyIAG, HV_BINOP_MULTIPLY, 1, m, &cBinop_aglgyIAG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aP6NJBWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_DngxixYs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YKN7kkP7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_UF5mxe0u_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UF5mxe0u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sfwloA9, HV_BINOP_MULTIPLY, 1, m, &cBinop_6sfwloA9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iudXxqZ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZZANUoc, HV_BINOP_MULTIPLY, 1, m, &cBinop_FZZANUoc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iE4ySXlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iudXxqZ2_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zuMsIMrM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1SfD0WEn, HV_BINOP_MULTIPLY, 1, m, &cBinop_1SfD0WEn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MPLV2Hnk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_QGON7Gpi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QGON7Gpi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UiFU52Ln, HV_BINOP_MULTIPLY, 1, m, &cBinop_UiFU52Ln_sendMessage);
}

void Heavy_WSTD_3Q::cVar_thchjqAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0ZNGxYap_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_YzjD2r0e_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N9kHFul3_sendMessage);
}

void Heavy_WSTD_3Q::cVar_4ejy3hEU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Q7KeLEgC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YUzNv9Jw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_v12I5oPs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_txEqzvb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_IHnaejYq_sendMessage);
}

void Heavy_WSTD_3Q::cSend_lW1Z7FtR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XBzMUAW9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ymfFMjGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iuJoMuaZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_X1sne9wc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CpoOoIrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_OKMSOTTm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_833qxwK4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_833qxwK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l4Etbe1M, HV_BINOP_MULTIPLY, 1, m, &cBinop_l4Etbe1M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l4Etbe1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tZRMjLo6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tZRMjLo6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_X1sne9wc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_T9HuFSFz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_UlfoVLUR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UlfoVLUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wujXK2JA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MOwvIfGk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hPFTQsvM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vZCbV2Sr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2YFOOk5i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BpYP0RH8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aglgyIAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DVAjfVrm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6sfwloA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wR2UeDde_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FZZANUoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0xhdtSES_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1SfD0WEn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GGTeN4Fl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UiFU52Ln_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZkGAxhDb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_c99v9u1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4ejy3hEU, 1, m, &cVar_4ejy3hEU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xBTTTay8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_thchjqAv, 0, m, &cVar_thchjqAv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BpYP0RH8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aglgyIAG, HV_BINOP_MULTIPLY, 0, m, &cBinop_aglgyIAG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hPFTQsvM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1SfD0WEn, HV_BINOP_MULTIPLY, 0, m, &cBinop_1SfD0WEn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2YFOOk5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6sfwloA9, HV_BINOP_MULTIPLY, 0, m, &cBinop_6sfwloA9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MOwvIfGk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UiFU52Ln, HV_BINOP_MULTIPLY, 0, m, &cBinop_UiFU52Ln_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vZCbV2Sr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FZZANUoc, HV_BINOP_MULTIPLY, 0, m, &cBinop_FZZANUoc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wujXK2JA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_N9kHFul3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hHvLcb9Y, 0, m, &cVar_hHvLcb9Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0ZNGxYap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4ejy3hEU, 0, m, &cVar_4ejy3hEU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_j5XCkRQh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bjyTn0ul, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gWg2T8tb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_T6FJhdx3, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Bw8bWexh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HWJnPhcd, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0ZQxKO1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1yYRxGaP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zVHZEl3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nhwgNV4M_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_nhwgNV4M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_owfki8MN, HV_BINOP_DIVIDE, 1, m, &cBinop_owfki8MN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oHJx2jA1_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_eN9kcSGw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_11uW4S0t_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_7O1fGjgV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_eN9kcSGw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_11uW4S0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_owfki8MN, HV_BINOP_DIVIDE, 0, m, &cBinop_owfki8MN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oHJx2jA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7O1fGjgV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_owfki8MN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0llrnWP, HV_BINOP_MULTIPLY, 1, m, &cBinop_i0llrnWP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_i0llrnWP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_64QxZwtw_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3MGtkGH6_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_o0HhES5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nVDNJocW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_VGi5PhlN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WQgGYixP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_KfiT4MGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_6hiGz1m7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6hiGz1m7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i0llrnWP, HV_BINOP_MULTIPLY, 0, m, &cBinop_i0llrnWP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6cK92ZOK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5M3qeftq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5M3qeftq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bKmll41J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_yMt3lQO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLcxlVrX, HV_BINOP_MULTIPLY, 1, m, &cBinop_QLcxlVrX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SghY2J3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MO9R1rLq, 1, m, &cVar_MO9R1rLq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gMjOsHky_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VN0qMEao, HV_BINOP_MULTIPLY, 1, m, &cBinop_VN0qMEao_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_764WJoYN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_edZWS0f1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_edZWS0f1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qum97qRr, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qum97qRr_sendMessage);
}

void Heavy_WSTD_3Q::cVar_MO9R1rLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_362H4Xn4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_cnK7yfa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NOZRLo94_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_KfiT4MGf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QDBdkYyV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_krvO9D1I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6cK92ZOK_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3MGtkGH6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_VGi5PhlN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_64QxZwtw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_o0HhES5Z_sendMessage);
}

void Heavy_WSTD_3Q::cSend_nVDNJocW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PP3FzxpC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_WQgGYixP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ACMnY7hQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_RGW6ESgr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4aoqW1H9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_bKmll41J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_6ub9qy5B_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6ub9qy5B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yfgN9ohe, HV_BINOP_MULTIPLY, 1, m, &cBinop_yfgN9ohe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yfgN9ohe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_XSyXKNVY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XSyXKNVY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RGW6ESgr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_362H4Xn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3O9RP7qt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3O9RP7qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gba5FbY4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g2oCoyGu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xrFEgvXB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P5byT86u_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RukiJSx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j5XCkRQh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_QLcxlVrX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gWg2T8tb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_VN0qMEao_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Bw8bWexh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Qum97qRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0ZQxKO1h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_bKuaNgiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_krvO9D1I, 1, m, &cVar_krvO9D1I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_waJQqhJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cnK7yfa4, 0, m, &cVar_cnK7yfa4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NOZRLo94_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_krvO9D1I, 0, m, &cVar_krvO9D1I_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QDBdkYyV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MO9R1rLq, 0, m, &cVar_MO9R1rLq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xrFEgvXB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QLcxlVrX, HV_BINOP_MULTIPLY, 0, m, &cBinop_QLcxlVrX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_g2oCoyGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VN0qMEao, HV_BINOP_MULTIPLY, 0, m, &cBinop_VN0qMEao_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P5byT86u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RukiJSx2, HV_BINOP_MULTIPLY, 0, m, &cBinop_RukiJSx2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_gba5FbY4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qum97qRr, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qum97qRr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_o9iRXjDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HKtBKaOP, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_lDOvX1Da_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lgKTRnOX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_iZMxgLcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EY7QtDDf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_75hiNxdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x77LrN4I, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_4qOYZxkI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N0eC9Oiw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_HbIxdwKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2PLPetR5_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_2PLPetR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UPG2wGRz, HV_BINOP_DIVIDE, 1, m, &cBinop_UPG2wGRz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s9wmqbuR_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_YK7DyY21_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_VZHD22dr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0UvWm4Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_YK7DyY21_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VZHD22dr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UPG2wGRz, HV_BINOP_DIVIDE, 0, m, &cBinop_UPG2wGRz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_s9wmqbuR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0UvWm4Iy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UPG2wGRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Va0Z7wKU, HV_BINOP_MULTIPLY, 1, m, &cBinop_Va0Z7wKU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Va0Z7wKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RsBQqXBd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ITTswfF3_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3cPNF8oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DfLRtBLf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_alZSky3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_r4i6VBw0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_f749opNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_zl4RUCaB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zl4RUCaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Va0Z7wKU, HV_BINOP_MULTIPLY, 0, m, &cBinop_Va0Z7wKU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OHxaDn8r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_5QGOatF4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5QGOatF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fC711DlR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fIcjZq2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EdS6ko1m, HV_BINOP_MULTIPLY, 1, m, &cBinop_EdS6ko1m_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XhEf6Wvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_IwZQW30i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IwZQW30i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_fIcjZq2Z_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OQkXPBbo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bTH2rMcC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bTH2rMcC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nkHV2xp, HV_BINOP_MULTIPLY, 1, m, &cBinop_7nkHV2xp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gV7WWXOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBjsEYB3, HV_BINOP_MULTIPLY, 1, m, &cBinop_WBjsEYB3_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lP36qW2x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_W1K81YFA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_W1K81YFA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_gV7WWXOs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k6zYM77r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3tG01rl3, 1, m, &cVar_3tG01rl3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_L5DxiZir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8PZUKnFg, HV_BINOP_MULTIPLY, 1, m, &cBinop_8PZUKnFg_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4896buxT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Q8BfpGfO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Q8BfpGfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EQGbcvZ0, HV_BINOP_MULTIPLY, 1, m, &cBinop_EQGbcvZ0_sendMessage);
}

void Heavy_WSTD_3Q::cVar_3tG01rl3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vgr07wLO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_KjTLEyWJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_77JKZajD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_f749opNe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tqfpFaRH_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1Yk0bvea_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_OHxaDn8r_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RsBQqXBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3cPNF8oa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ITTswfF3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_alZSky3I_sendMessage);
}

void Heavy_WSTD_3Q::cSend_DfLRtBLf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e5kydQPC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_r4i6VBw0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cSFfVuDL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_VQosbggK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Ye53yNj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_fC711DlR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_gkpJeAat_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gkpJeAat_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YfyQ7oLe, HV_BINOP_MULTIPLY, 1, m, &cBinop_YfyQ7oLe_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YfyQ7oLe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZkfgMZjA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZkfgMZjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VQosbggK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_vgr07wLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KYfJR9jy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KYfJR9jy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_reFbqf9k_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PyX5MHFZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1qNsLS3j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3GLYcGOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0G4xTFkC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uxbGLp90_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EdS6ko1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o9iRXjDf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7nkHV2xp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lDOvX1Da_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WBjsEYB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_iZMxgLcp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_8PZUKnFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_75hiNxdc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EQGbcvZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4qOYZxkI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_QldqDqrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KjTLEyWJ, 0, m, &cVar_KjTLEyWJ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A6Gn3uR7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1Yk0bvea, 1, m, &cVar_1Yk0bvea_sendMessage);
}

void Heavy_WSTD_3Q::cCast_1qNsLS3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8PZUKnFg, HV_BINOP_MULTIPLY, 0, m, &cBinop_8PZUKnFg_sendMessage);
}

void Heavy_WSTD_3Q::cCast_0G4xTFkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7nkHV2xp, HV_BINOP_MULTIPLY, 0, m, &cBinop_7nkHV2xp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_PyX5MHFZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EQGbcvZ0, HV_BINOP_MULTIPLY, 0, m, &cBinop_EQGbcvZ0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3GLYcGOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WBjsEYB3, HV_BINOP_MULTIPLY, 0, m, &cBinop_WBjsEYB3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_reFbqf9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_uxbGLp90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EdS6ko1m, HV_BINOP_MULTIPLY, 0, m, &cBinop_EdS6ko1m_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tqfpFaRH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3tG01rl3, 0, m, &cVar_3tG01rl3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_77JKZajD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1Yk0bvea, 0, m, &cVar_1Yk0bvea_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_nDpTDoUa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IM6GLCn0, 1, m, &cIf_IM6GLCn0_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9RxX8SHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_nn0B6IAv, m);
}

void Heavy_WSTD_3Q::cBinop_MB76BsGy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9RxX8SHR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_PYM2QIwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IM6GLCn0, 0, m, &cIf_IM6GLCn0_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_5dXw1M7f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Dc6hFHbY, 0, m, &cSlice_Dc6hFHbY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_tn2p9a3c_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Dc6hFHbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fLAxXomw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fLAxXomw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_aE9fhZjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fLAxXomw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_fLAxXomw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ToQr5GFC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_1pv39uQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YeJ6HWT2_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_G9BFKhDg, 0, m, &cIf_G9BFKhDg_sendMessage);
}

void Heavy_WSTD_3Q::cIf_G9BFKhDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_usneKqMU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_3KA1OzP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_i3tGxGyR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_7p2cg6Sp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_89ArdrEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ok0SkIn6, HV_BINOP_POW, 0, m, &cBinop_Ok0SkIn6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ok0SkIn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h8MbmfLP, 0, m, &cIf_h8MbmfLP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HbFwYNXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pIVLr2Mp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YFzslw5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3KA1OzP9, 0, m, &cIf_3KA1OzP9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XGaricDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_B1frDIEG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_B1frDIEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3KA1OzP9, 1, m, &cIf_3KA1OzP9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7p2cg6Sp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_HbFwYNXs_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_i3tGxGyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_h8MbmfLP, 0, m, &cIf_h8MbmfLP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pIVLr2Mp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ok0SkIn6, HV_BINOP_POW, 1, m, &cBinop_Ok0SkIn6_sendMessage);
  cMsg_89ArdrEd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_h8MbmfLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_tTh6khHZ, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_YeJ6HWT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G9BFKhDg, 1, m, &cIf_G9BFKhDg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_usneKqMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mS8AZZbj, HV_BINOP_GREATER_THAN, 1, m, &cBinop_mS8AZZbj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECh1JYbO, HV_BINOP_EQ, 1, m, &cBinop_ECh1JYbO_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_cQXNHvc2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WRu0wBr, HV_BINOP_ADD, 0, m, &cBinop_6WRu0wBr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6WRu0wBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XGaricDW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFzslw5m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mS8AZZbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h8MbmfLP, 1, m, &cIf_h8MbmfLP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ECh1JYbO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gmh2NWKq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Gmh2NWKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_tTh6khHZ, m);
}

void Heavy_WSTD_3Q::cCast_qqHRS4OX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1pv39uQo, 0, m, &cVar_1pv39uQo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zwDgFzhU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cQXNHvc2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_XixvAWaL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6WRu0wBr, HV_BINOP_ADD, 1, m, &cBinop_6WRu0wBr_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mS8AZZbj, HV_BINOP_GREATER_THAN, 0, m, &cBinop_mS8AZZbj_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ECh1JYbO, HV_BINOP_EQ, 0, m, &cBinop_ECh1JYbO_sendMessage);
}

void Heavy_WSTD_3Q::cVar_B7eEIN3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PnjzaIXq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_s6DxMIdA, 0, m, &cIf_s6DxMIdA_sendMessage);
}

void Heavy_WSTD_3Q::cIf_s6DxMIdA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ZJnx1S3W_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_pKFgsmae_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_AFW6gRiK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mfiVyvvH_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_UOw15plc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_46NpLZqS, HV_BINOP_POW, 0, m, &cBinop_46NpLZqS_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_46NpLZqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GoYf6Y4G, 0, m, &cIf_GoYf6Y4G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_XSlKFNSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_k7Fomori_sendMessage);
}

void Heavy_WSTD_3Q::cCast_B2t2cCqL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pKFgsmae, 0, m, &cIf_pKFgsmae_sendMessage);
}

void Heavy_WSTD_3Q::cCast_P3Jv261M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_S2e55Z88_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_S2e55Z88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pKFgsmae, 1, m, &cIf_pKFgsmae_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mfiVyvvH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_XSlKFNSM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_AFW6gRiK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_GoYf6Y4G, 0, m, &cIf_GoYf6Y4G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_k7Fomori_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_46NpLZqS, HV_BINOP_POW, 1, m, &cBinop_46NpLZqS_sendMessage);
  cMsg_UOw15plc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_GoYf6Y4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9MFl4zYV_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DwXrPztW_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bGXoyzTn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_PnjzaIXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_s6DxMIdA, 1, m, &cIf_s6DxMIdA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZJnx1S3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2lKSsd0, HV_BINOP_GREATER_THAN, 1, m, &cBinop_V2lKSsd0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm4eFh1H, HV_BINOP_EQ, 1, m, &cBinop_Wm4eFh1H_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_d5jRCwTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_lVMtxKUc, HV_BINOP_ADD, 0, m, &cBinop_lVMtxKUc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lVMtxKUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P3Jv261M_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_B2t2cCqL_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_V2lKSsd0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GoYf6Y4G, 1, m, &cIf_GoYf6Y4G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Wm4eFh1H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IlUvGcZB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_IlUvGcZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9MFl4zYV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DwXrPztW_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_bGXoyzTn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uGhdF110_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lVMtxKUc, HV_BINOP_ADD, 1, m, &cBinop_lVMtxKUc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_V2lKSsd0, HV_BINOP_GREATER_THAN, 0, m, &cBinop_V2lKSsd0_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Wm4eFh1H, HV_BINOP_EQ, 0, m, &cBinop_Wm4eFh1H_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yzGZ5vqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B7eEIN3t, 0, m, &cVar_B7eEIN3t_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2jN5BfSu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_d5jRCwTp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_wm7juNpq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7kr7sHBR_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_UR394G2i, 0, m, &cIf_UR394G2i_sendMessage);
}

void Heavy_WSTD_3Q::cIf_UR394G2i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_poG5vtF9_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_Z11vxy2G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_4yg3ntoH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_0sgcPkWU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_d8xTFxYI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vS8jeIyu, HV_BINOP_POW, 0, m, &cBinop_vS8jeIyu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vS8jeIyu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsANafHX, 0, m, &cIf_gsANafHX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xwma9IVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_2YLH1TOh_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yky1f1bc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z11vxy2G, 0, m, &cIf_Z11vxy2G_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jeQVocl9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uYeCGvb4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uYeCGvb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z11vxy2G, 1, m, &cIf_Z11vxy2G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0sgcPkWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_xwma9IVT_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_4yg3ntoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_gsANafHX, 0, m, &cIf_gsANafHX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2YLH1TOh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vS8jeIyu, HV_BINOP_POW, 1, m, &cBinop_vS8jeIyu_sendMessage);
  cMsg_d8xTFxYI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_gsANafHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_qChAGPLP, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_7kr7sHBR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UR394G2i, 1, m, &cIf_UR394G2i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_poG5vtF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfpFUprG, HV_BINOP_GREATER_THAN, 1, m, &cBinop_UfpFUprG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4KMVHEnF, HV_BINOP_EQ, 1, m, &cBinop_4KMVHEnF_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_MBnKVj4N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3XKx0n74, HV_BINOP_ADD, 0, m, &cBinop_3XKx0n74_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3XKx0n74_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jeQVocl9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yky1f1bc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UfpFUprG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gsANafHX, 1, m, &cIf_gsANafHX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4KMVHEnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tok9C0Uu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Tok9C0Uu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_qChAGPLP, m);
}

void Heavy_WSTD_3Q::cCast_DCHZduUX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MBnKVj4N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_0b2H7ZAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3XKx0n74, HV_BINOP_ADD, 1, m, &cBinop_3XKx0n74_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UfpFUprG, HV_BINOP_GREATER_THAN, 0, m, &cBinop_UfpFUprG_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4KMVHEnF, HV_BINOP_EQ, 0, m, &cBinop_4KMVHEnF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WllA24qZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wm7juNpq, 0, m, &cVar_wm7juNpq_sendMessage);
}

void Heavy_WSTD_3Q::cIf_ci9WdWdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_odIvW8qv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_NFGQaaGr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DbYjm8RG, 0, m, &cSlice_DbYjm8RG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zM5lD5W2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DbYjm8RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iqcV6cr3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iqcV6cr3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_fcaABzOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iqcV6cr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iqcV6cr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YSjm2SNO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_zM5lD5W2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DxQXCwfv, 0, m, &cSlice_DxQXCwfv_sendMessage);
      break;
    }
    default: {
      cSwitchcase_5dXw1M7f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_DxQXCwfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gLPkuGdE_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gLPkuGdE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_rq1sqZHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gLPkuGdE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_gLPkuGdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dETiLOrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_tn2p9a3c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BePseq2O, 0, m, &cSlice_BePseq2O_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2PKJQG4C_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_BePseq2O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_YBGqZNoY_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_YBGqZNoY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_FFdwLXKz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_YBGqZNoY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_YBGqZNoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_vA4epq47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_2PKJQG4C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zsFgQiZP, 0, m, &cSlice_zsFgQiZP_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_zsFgQiZP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Zd0u3gx5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Zd0u3gx5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_Z7TFCdZ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Zd0u3gx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Zd0u3gx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9SAmCMJ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_4CB1rDii_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8eUUeNKB, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_PLyBfOWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jhQBY1Ea, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_itZYoawt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CkFs0LQf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_h1Z7OWWW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c7k0EEGw, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_HXrLQouy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WH4fj1en, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_N3XXhHsR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_sIeUTOYq_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_sIeUTOYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qpGm5N6Y, HV_BINOP_DIVIDE, 1, m, &cBinop_qpGm5N6Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QluHq54j_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_vycbWiuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_lPERncM5_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_GAD8QANm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_vycbWiuU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lPERncM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qpGm5N6Y, HV_BINOP_DIVIDE, 0, m, &cBinop_qpGm5N6Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QluHq54j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GAD8QANm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qpGm5N6Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KejDW5zF, HV_BINOP_MULTIPLY, 1, m, &cBinop_KejDW5zF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KejDW5zF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pfFkvaYy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BedVp1qe_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ZLOI01k1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_njG7YLsB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_FkO8pMGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tu2AOL8m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ImcMGHPw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_CusdKP0e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CusdKP0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KejDW5zF, HV_BINOP_MULTIPLY, 0, m, &cBinop_KejDW5zF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YgBkynBt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Mtl7731i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Mtl7731i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Yoqyp2eS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_L0Jp3ucT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h51rSdZG, 1, m, &cVar_h51rSdZG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_h51rSdZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2U9gvUJq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_j8gfGKxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMbcImMB, HV_BINOP_MULTIPLY, 1, m, &cBinop_OMbcImMB_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_a5xZOZyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_j8gfGKxR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7M2rgUVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_mG1L2LMs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mG1L2LMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvzwmU7Y, HV_BINOP_MULTIPLY, 1, m, &cBinop_lvzwmU7Y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_szFtIwM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6QaRt5XI, HV_BINOP_MULTIPLY, 1, m, &cBinop_6QaRt5XI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cx325fxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_szFtIwM1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vXH10NZN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUnZ5n4n, HV_BINOP_MULTIPLY, 1, m, &cBinop_aUnZ5n4n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UcG0Oj3c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CjII0z7G_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CjII0z7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEH0HbrG, HV_BINOP_MULTIPLY, 1, m, &cBinop_UEH0HbrG_sendMessage);
}

void Heavy_WSTD_3Q::cVar_EomUcLpt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A8p7PdjG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ImcMGHPw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8L9NSlKg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_QFrTLucU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_YgBkynBt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_pfFkvaYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_ZLOI01k1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BedVp1qe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FkO8pMGd_sendMessage);
}

void Heavy_WSTD_3Q::cSend_njG7YLsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XKSRgq90_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_tu2AOL8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bowaaJVh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_RmAOuEYK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xCW8jKfK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Yoqyp2eS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_60wyfQ4F_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_60wyfQ4F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7BfLdVoI, HV_BINOP_MULTIPLY, 1, m, &cBinop_7BfLdVoI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7BfLdVoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I2mtf9y5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_I2mtf9y5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RmAOuEYK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2U9gvUJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_02kAbH3a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_02kAbH3a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7SKOFyH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GUknplno_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zftvrUMJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_17dOEdOj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3hi2STrq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zSnNWR3w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OMbcImMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4CB1rDii_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lvzwmU7Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PLyBfOWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_6QaRt5XI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_itZYoawt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aUnZ5n4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h1Z7OWWW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UEH0HbrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HXrLQouy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_L20sRMLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_EomUcLpt, 0, m, &cVar_EomUcLpt_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YRhs00tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QFrTLucU, 1, m, &cVar_QFrTLucU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_3hi2STrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lvzwmU7Y, HV_BINOP_MULTIPLY, 0, m, &cBinop_lvzwmU7Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GUknplno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UEH0HbrG, HV_BINOP_MULTIPLY, 0, m, &cBinop_UEH0HbrG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_17dOEdOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6QaRt5XI, HV_BINOP_MULTIPLY, 0, m, &cBinop_6QaRt5XI_sendMessage);
}

void Heavy_WSTD_3Q::cCast_v7SKOFyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_zSnNWR3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OMbcImMB, HV_BINOP_MULTIPLY, 0, m, &cBinop_OMbcImMB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_zftvrUMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUnZ5n4n, HV_BINOP_MULTIPLY, 0, m, &cBinop_aUnZ5n4n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_A8p7PdjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QFrTLucU, 0, m, &cVar_QFrTLucU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8L9NSlKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_h51rSdZG, 0, m, &cVar_h51rSdZG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_N9A1mVyf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_C9e6lydZ, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kOxDNlu8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_blevvN0Q, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MtgZl2HV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v3BdW2jj, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_xmxyztPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BKnidlwI, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6x0olbpL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_YhjNomGD_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_YhjNomGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rCFH8q9, HV_BINOP_DIVIDE, 1, m, &cBinop_1rCFH8q9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HEw27yOO_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_3yjvQcgi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_WXJmtsER_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_5X8aypks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_3yjvQcgi_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WXJmtsER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1rCFH8q9, HV_BINOP_DIVIDE, 0, m, &cBinop_1rCFH8q9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HEw27yOO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5X8aypks_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_1rCFH8q9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mO5fsQRU, HV_BINOP_MULTIPLY, 1, m, &cBinop_mO5fsQRU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_mO5fsQRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zu1hqXun_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vnmMFVtZ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_smmEiVIG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UKFsd2Ai_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_dyUUyRMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_KgcpRJf3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ID2XXtAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wvNh7Ja8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wvNh7Ja8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mO5fsQRU, HV_BINOP_MULTIPLY, 0, m, &cBinop_mO5fsQRU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bpwdd4sa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_98WtW6Om_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_98WtW6Om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oRWYx3aW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_7OENUNmH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S2lCjVm4, HV_BINOP_MULTIPLY, 1, m, &cBinop_S2lCjVm4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_p9hdCIs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWzhGO0i, 1, m, &cVar_VWzhGO0i_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0JM6bob5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jsrrg4tf, HV_BINOP_MULTIPLY, 1, m, &cBinop_Jsrrg4tf_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_vr8hFrBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AiBWmspn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_AiBWmspn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_abIYtoS4, HV_BINOP_MULTIPLY, 1, m, &cBinop_abIYtoS4_sendMessage);
}

void Heavy_WSTD_3Q::cVar_VWzhGO0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oXuQhBGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_nOf3baMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qKB4t17C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_ID2XXtAV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wbOtfzic_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Dqobq5kX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Bpwdd4sa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vnmMFVtZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_dyUUyRMs_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Zu1hqXun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_smmEiVIG_sendMessage);
}

void Heavy_WSTD_3Q::cSend_UKFsd2Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2Vkkrjet_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_KgcpRJf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P3pugtA2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_2VzdmYk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YNPcNYxM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_oRWYx3aW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_3ygur5vP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3ygur5vP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3c0vabK, HV_BINOP_MULTIPLY, 1, m, &cBinop_j3c0vabK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_j3c0vabK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MpNpJvVV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MpNpJvVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2VzdmYk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_oXuQhBGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_d8JvBLyP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d8JvBLyP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bIIE2v8m_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HkwJwBzX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Xd0FY8JL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vP6rvu9k_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aNUf1S65_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N9A1mVyf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_S2lCjVm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kOxDNlu8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Jsrrg4tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MtgZl2HV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_abIYtoS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xmxyztPp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_WdkBOy90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dqobq5kX, 1, m, &cVar_Dqobq5kX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ldmyBX4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nOf3baMo, 0, m, &cVar_nOf3baMo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qKB4t17C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Dqobq5kX, 0, m, &cVar_Dqobq5kX_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wbOtfzic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VWzhGO0i, 0, m, &cVar_VWzhGO0i_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Xd0FY8JL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_S2lCjVm4, HV_BINOP_MULTIPLY, 0, m, &cBinop_S2lCjVm4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_HkwJwBzX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Jsrrg4tf, HV_BINOP_MULTIPLY, 0, m, &cBinop_Jsrrg4tf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vP6rvu9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNUf1S65, HV_BINOP_MULTIPLY, 0, m, &cBinop_aNUf1S65_sendMessage);
}

void Heavy_WSTD_3Q::cCast_bIIE2v8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_abIYtoS4, HV_BINOP_MULTIPLY, 0, m, &cBinop_abIYtoS4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8pj2Bffu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XX3iJo8O, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_OG1jRA2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1V0Pa2r9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_gnawdwDw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vRwebZIu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_HNjNn59Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gmfg1MOu, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QPxyICsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kSqeGiE9, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_jbW2hm5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ICV4PYuG_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_ICV4PYuG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shQci16U, HV_BINOP_DIVIDE, 1, m, &cBinop_shQci16U_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wb52pH7j_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_H1NNYtAX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_4RzzHd7F_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8NlU8QLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_H1NNYtAX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4RzzHd7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_shQci16U, HV_BINOP_DIVIDE, 0, m, &cBinop_shQci16U_sendMessage);
}

void Heavy_WSTD_3Q::cCast_wb52pH7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8NlU8QLw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_shQci16U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqYIiGtD, HV_BINOP_MULTIPLY, 1, m, &cBinop_BqYIiGtD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BqYIiGtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kYEOU0mG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RbG7OD92_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_Z9pecVhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_qUITOhnm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_bhvP4XTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JT2jnHXb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_igNuZw9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_IVmVxVBs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IVmVxVBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqYIiGtD, HV_BINOP_MULTIPLY, 0, m, &cBinop_BqYIiGtD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8v3VNhhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_kKmulFqN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_kKmulFqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ydDWmf88_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SdEOdlbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvaXVv5A, HV_BINOP_MULTIPLY, 1, m, &cBinop_YvaXVv5A_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_oPsnOKjG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_bBXxsExh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bBXxsExh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SdEOdlbH_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8ZD0BDmV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_eKARZg2b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eKARZg2b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUxvaqH1, HV_BINOP_MULTIPLY, 1, m, &cBinop_FUxvaqH1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oGauMkzA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIKv31BG, HV_BINOP_MULTIPLY, 1, m, &cBinop_cIKv31BG_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_P5iDDf7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_tH55bjRu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tH55bjRu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_oGauMkzA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7A6x9ZRp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VQSIvLki, 1, m, &cVar_VQSIvLki_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bKcUn6ta_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3FPeE38, HV_BINOP_MULTIPLY, 1, m, &cBinop_V3FPeE38_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OWsGOP47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_opAb5wpy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_opAb5wpy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EuWqEsoa, HV_BINOP_MULTIPLY, 1, m, &cBinop_EuWqEsoa_sendMessage);
}

void Heavy_WSTD_3Q::cVar_VQSIvLki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_do1H24U6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_ksKgwpfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RickiXbi_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_igNuZw9x_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DKsTrxbF_sendMessage);
}

void Heavy_WSTD_3Q::cVar_HBL8lOWv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_8v3VNhhG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RbG7OD92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_bhvP4XTQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_kYEOU0mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Z9pecVhg_sendMessage);
}

void Heavy_WSTD_3Q::cSend_qUITOhnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SjoHbvfA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JT2jnHXb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k1rlzysn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_9r4UhWXe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_k9nlq2Qx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_ydDWmf88_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8jbh0zWo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8jbh0zWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIhz5w4A, HV_BINOP_MULTIPLY, 1, m, &cBinop_NIhz5w4A_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_NIhz5w4A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yV4mK74Z_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yV4mK74Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_9r4UhWXe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_do1H24U6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SJyglm68_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SJyglm68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AplAEhQv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dPJCnzAp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Z8anSeNH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CIz1fxtD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6F5ZmoNm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dMhfmz7w_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YvaXVv5A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8pj2Bffu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FUxvaqH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OG1jRA2g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_cIKv31BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gnawdwDw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_V3FPeE38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HNjNn59Q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_EuWqEsoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QPxyICsr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_oJccW5gi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ksKgwpfx, 0, m, &cVar_ksKgwpfx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JRWVa8Vp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HBL8lOWv, 1, m, &cVar_HBL8lOWv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_6F5ZmoNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FUxvaqH1, HV_BINOP_MULTIPLY, 0, m, &cBinop_FUxvaqH1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dPJCnzAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EuWqEsoa, HV_BINOP_MULTIPLY, 0, m, &cBinop_EuWqEsoa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CIz1fxtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cIKv31BG, HV_BINOP_MULTIPLY, 0, m, &cBinop_cIKv31BG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AplAEhQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_dMhfmz7w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YvaXVv5A, HV_BINOP_MULTIPLY, 0, m, &cBinop_YvaXVv5A_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Z8anSeNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_V3FPeE38, HV_BINOP_MULTIPLY, 0, m, &cBinop_V3FPeE38_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DKsTrxbF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_VQSIvLki, 0, m, &cVar_VQSIvLki_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RickiXbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HBL8lOWv, 0, m, &cVar_HBL8lOWv_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9MFl4zYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ci9WdWdn, 1, m, &cIf_ci9WdWdn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UO28TAir_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_odIvW8qv, m);
}

void Heavy_WSTD_3Q::cBinop_DwXrPztW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UO28TAir_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bGXoyzTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ci9WdWdn, 0, m, &cIf_ci9WdWdn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_62Syh1Mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UB9Arvkn, HV_BINOP_DIVIDE, 0, m, &cBinop_UB9Arvkn_sendMessage);
}

void Heavy_WSTD_3Q::cVar_bLy9H08s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zHFS0uBk, HV_BINOP_DIVIDE, 1, m, &cBinop_zHFS0uBk_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_UB9Arvkn, HV_BINOP_DIVIDE, 1, m, &cBinop_UB9Arvkn_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_2XK1GOPW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hjBowllz, HV_BINOP_DIVIDE, 0, m, &cBinop_hjBowllz_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_SGYvu0NK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hjBowllz, HV_BINOP_DIVIDE, 1, m, &cBinop_hjBowllz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_V3FE6hJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zHFS0uBk, HV_BINOP_DIVIDE, 0, m, &cBinop_zHFS0uBk_sendMessage);
}

void Heavy_WSTD_3Q::cCast_WyN97ZJu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_62Syh1Mf, 0, m, &cVar_62Syh1Mf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_fSyAvAXj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bLy9H08s, 0, m, &cVar_bLy9H08s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zHFS0uBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_2XK1GOPW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UB9Arvkn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_SGYvu0NK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hjBowllz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_1AbQcg4Z_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fU6v2ryC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_TH7e58og_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gLA9flvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_h8IuSoKE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1AbQcg4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_gLA9flvf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_h8IuSoKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_fU6v2ryC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TH7e58og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BQ6QS5jN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_2I7W9b8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_C4z9Kby1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NFGQaaGr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_w0LzNNlc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_C4z9Kby1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NFGQaaGr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_kpKOmhBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_C4z9Kby1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NFGQaaGr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yripBUfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_C4z9Kby1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NFGQaaGr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BQ6QS5jN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_C4z9Kby1_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_NFGQaaGr_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_MOK46JeK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_aCLASHWl, 0, m, &cVar_aCLASHWl_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_S9p220vr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xfmm8CsJ, 0, m, &cVar_xfmm8CsJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZSdYPgSw, 0, m, &cVar_ZSdYPgSw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HxX3c4a2, 0, m, &cVar_HxX3c4a2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_qCiMffLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xfmm8CsJ, 0, m, &cVar_xfmm8CsJ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_QDm6r6sW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZSdYPgSw, 0, m, &cVar_ZSdYPgSw_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_mBRjsbQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HxX3c4a2, 0, m, &cVar_HxX3c4a2_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_lBw1P239_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cnK7yfa4, 0, m, &cVar_cnK7yfa4_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_3eUb2Mvy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bKuaNgiI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_waJQqhJu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vjC8UlGb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xxeEKhu6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iXJgsSLG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l9zVzKwt_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_uZiKGaHK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ApuEXJaH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVAfYQeT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_S1F6CUIi_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_4CXtiqFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wz8dqjFx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_X31y9xQr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7RXTpq33_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_nb0EmIIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WETIPFwC_sendMessage(_c, 0, m);
  cMsg_zVHZEl3X_sendMessage(_c, 0, m);
  cMsg_HbIxdwKQ_sendMessage(_c, 0, m);
  cMsg_N3XXhHsR_sendMessage(_c, 0, m);
  cMsg_6x0olbpL_sendMessage(_c, 0, m);
  cMsg_jbW2hm5I_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_thchjqAv, 0, m, &cVar_thchjqAv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cnK7yfa4, 0, m, &cVar_cnK7yfa4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_KjTLEyWJ, 0, m, &cVar_KjTLEyWJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EomUcLpt, 0, m, &cVar_EomUcLpt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nOf3baMo, 0, m, &cVar_nOf3baMo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ksKgwpfx, 0, m, &cVar_ksKgwpfx_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eDDwGNl0, 0, m, &cVar_eDDwGNl0_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HTPTmcdj, 0, m, &cVar_HTPTmcdj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SgJqrzYK, 0, m, &cVar_SgJqrzYK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_VhL3siJ5, 0, m, &cVar_VhL3siJ5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9hyqRfLO, 0, m, &cVar_9hyqRfLO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Jzxt5vSo, 0, m, &cVar_Jzxt5vSo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tB52nXMq, 0, m, &cVar_tB52nXMq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A4qGJ8kV, 0, m, &cVar_A4qGJ8kV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aE9fhZjS, 0, m, &cVar_aE9fhZjS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1pv39uQo, 0, m, &cVar_1pv39uQo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B7eEIN3t, 0, m, &cVar_B7eEIN3t_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wm7juNpq, 0, m, &cVar_wm7juNpq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_fcaABzOS, 0, m, &cVar_fcaABzOS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rq1sqZHW, 0, m, &cVar_rq1sqZHW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FFdwLXKz, 0, m, &cVar_FFdwLXKz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z7TFCdZ5, 0, m, &cVar_Z7TFCdZ5_sendMessage);
  cMsg_S9p220vr_sendMessage(_c, 0, m);
  cMsg_MOK46JeK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_XBzMUAW9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_l4Etbe1M, HV_BINOP_MULTIPLY, 0, m, &cBinop_l4Etbe1M_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iuJoMuaZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_aP6NJBWN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_YKN7kkP7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iE4ySXlu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zuMsIMrM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CpoOoIrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_BZ0RrdLW_sendMessage);
  cMsg_MPLV2Hnk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_PP3FzxpC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yfgN9ohe, HV_BINOP_MULTIPLY, 0, m, &cBinop_yfgN9ohe_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ACMnY7hQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gMjOsHky_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_4aoqW1H9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RukiJSx2, HV_BINOP_MULTIPLY, 1, m, &cBinop_RukiJSx2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yMt3lQO1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_SghY2J3x_sendMessage);
  cMsg_764WJoYN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_e5kydQPC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YfyQ7oLe, HV_BINOP_MULTIPLY, 0, m, &cBinop_YfyQ7oLe_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cSFfVuDL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XhEf6Wvr_sendMessage(_c, 0, m);
  cMsg_OQkXPBbo_sendMessage(_c, 0, m);
  cMsg_lP36qW2x_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_L5DxiZir_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Ye53yNj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_k6zYM77r_sendMessage);
  cMsg_4896buxT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_ToQr5GFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_nOf3baMo, 0, m, &cVar_nOf3baMo_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9SAmCMJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WdkBOy90_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ldmyBX4o_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YSjm2SNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qqHRS4OX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XixvAWaL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zwDgFzhU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_vA4epq47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WllA24qZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0b2H7ZAj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DCHZduUX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_dETiLOrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yzGZ5vqd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uGhdF110_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2jN5BfSu_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_XKSRgq90_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7BfLdVoI, HV_BINOP_MULTIPLY, 0, m, &cBinop_7BfLdVoI_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_bowaaJVh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_a5xZOZyw_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7M2rgUVF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_cx325fxF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_vXH10NZN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_xCW8jKfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_L0Jp3ucT_sendMessage);
  cMsg_UcG0Oj3c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_2Vkkrjet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j3c0vabK, HV_BINOP_MULTIPLY, 0, m, &cBinop_j3c0vabK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_P3pugtA2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_0JM6bob5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_YNPcNYxM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aNUf1S65, HV_BINOP_MULTIPLY, 1, m, &cBinop_aNUf1S65_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_7OENUNmH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_p9hdCIs8_sendMessage);
  cMsg_vr8hFrBA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_SjoHbvfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NIhz5w4A, HV_BINOP_MULTIPLY, 0, m, &cBinop_NIhz5w4A_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_k1rlzysn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oPsnOKjG_sendMessage(_c, 0, m);
  cMsg_8ZD0BDmV_sendMessage(_c, 0, m);
  cMsg_P5iDDf7v_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_bKcUn6ta_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_k9nlq2Qx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_7A6x9ZRp_sendMessage);
  cMsg_OWsGOP47_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_ALMydOYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aCLASHWl, 0, m, &cVar_aCLASHWl_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_m82Ti6fe, VOf(Bf0));
    __hv_line_f(&sLine_gwx6banl, VOf(Bf1));
    __hv_line_f(&sLine_tXeKiija, VOf(Bf2));
    __hv_line_f(&sLine_7oieIj8y, VOf(Bf3));
    __hv_line_f(&sLine_Q880YTkb, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_O6ZIPI1t, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_GSO9aFv3, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_bjyTn0ul, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_T6FJhdx3, VOf(Bf1));
    __hv_line_f(&sLine_HWJnPhcd, VOf(Bf0));
    __hv_line_f(&sLine_1yYRxGaP, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_BQRSC4lJ, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_nn0B6IAv, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_HKtBKaOP, VOf(Bf5));
    __hv_line_f(&sLine_lgKTRnOX, VOf(Bf1));
    __hv_line_f(&sLine_EY7QtDDf, VOf(Bf2));
    __hv_line_f(&sLine_x77LrN4I, VOf(Bf4));
    __hv_line_f(&sLine_N0eC9Oiw, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_oFICHk5h, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Yia3d8cc, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_8eUUeNKB, VOf(Bf6));
    __hv_line_f(&sLine_jhQBY1Ea, VOf(Bf2));
    __hv_line_f(&sLine_CkFs0LQf, VOf(Bf1));
    __hv_line_f(&sLine_c7k0EEGw, VOf(Bf5));
    __hv_line_f(&sLine_WH4fj1en, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_2uJWMuI7, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_tTh6khHZ, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_C9e6lydZ, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_blevvN0Q, VOf(Bf2));
    __hv_line_f(&sLine_v3BdW2jj, VOf(Bf6));
    __hv_line_f(&sLine_BKnidlwI, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_hUffdJsB, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_odIvW8qv, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_XX3iJo8O, VOf(Bf8));
    __hv_line_f(&sLine_1V0Pa2r9, VOf(Bf2));
    __hv_line_f(&sLine_vRwebZIu, VOf(Bf1));
    __hv_line_f(&sLine_Gmfg1MOu, VOf(Bf7));
    __hv_line_f(&sLine_kSqeGiE9, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_h5P6ClQn, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_qChAGPLP, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
